@@ -194,7 +194,7 @@ const EPdfWriteMode ePdfWriteMode_Default = ePdfWriteMode_Compact;
  *
  * Remember to update PdfVariant::GetDataTypeString() when adding members here.
  */
-enum EPdfDataType PODOFO_ENUM_UINT8 {
+enum EPdfDataType {
     ePdfDataType_Bool,                  /**< Boolean datatype: Accepts the values "true" and "false" */
     ePdfDataType_Number,                /**< Number datatype for integer values */
     ePdfDataType_Real,                  /**< Real datatype for floating point numbers */
@@ -208,7 +208,7 @@ enum EPdfDataType PODOFO_ENUM_UINT8 {
     ePdfDataType_Reference,             /**< The reference datatype contains references to PDF objects in the PDF file of the form 4 0 R. \see PdfObject */
     ePdfDataType_RawData,               /**< Raw PDF data */
 
-    ePdfDataType_Unknown                /**< The Datatype is unknown */
+    ePdfDataType_Unknown = 0xff         /**< The Datatype is unknown. The value is chosen to enable value storage in 8-bit unsigned integer. */
 };
 
 /**
